{
  pkgs,
  config,
  ...
}: {
  imports = [
    ./aerc.nix
    ./atuin.nix
    ./bat.nix
    ./bottom.nix
    ./eza.nix
    ./fzf.nix
    ./git.nix
    ./go.nix
    ./gpg.nix
    #./helix.nix
    ./jj.nix
    ./jq.nix
    ./lazygit.nix
    ./nushell.nix
    ./oh-my-posh.nix
    ./senpai.nix
    ./ssh.nix
    ./xdg.nix
    ./zoxide.nix
  ];
  home = {
    packages = with pkgs; [
      # Tools
      age
      bitwarden-cli
      cachix
      duf
      du-dust
      fd
      git-absorb
      just
      ripgrep
      usql

      # Dhall
      dhall
      dhall-nix
      dhall-lsp-server

      # LSPs
      gopls
      nil

      # Jsonnet
      go-jsonnet
      jsonnet-language-server

      # Formatters
      alejandra
      gofumpt

      # Flake overlays
      jolheiser.gist
      jolheiser.git-age
      tclip
      templ
      jolheiser.helix
      jolheiser.tmpl
      jolheiser.gomodinit
      jolheiser.cfg
    ];
    activation.report-changes = config.lib.dag.entryAnywhere ''
      ${pkgs.nvd}/bin/nvd --nix-bin-dir=${pkgs.nix}/bin diff $oldGenPath $newGenPath
    '';
    stateVersion = "22.11";
  };

  xdg.configFile."gist/config.yaml".text = ''
    username: jolheiser
    password-file: ${config.age.secrets.gist-pw.path}
    domain: gist.jojodev.com
  '';

  programs.home-manager.enable = true;
}
