{pkgs, ...}: {
  console.colors = [
    "1e1e2e"
    "585b70"

    "bac2de"
    "a6adc8"

    "f38ba8"
    "f38ba8"

    "a6e3a1"
    "a6e3a1"

    "f9e2af"
    "f9e2af"

    "89b4fa"
    "89b4fa"

    "f5c2e7"
    "f5c2e7"

    "94e2d5"
    "94e2d5"
  ];

  time.timeZone = "America/Chicago";
  i18n.defaultLocale = "en_US.UTF-8";
  i18n.extraLocaleSettings = {
    LC_ADDRESS = "en_US.UTF-8";
    LC_IDENTIFICATION = "en_US.UTF-8";
    LC_MEASUREMENT = "en_US.UTF-8";
    LC_MONETARY = "en_US.UTF-8";
    LC_NAME = "en_US.UTF-8";
    LC_NUMERIC = "en_US.UTF-8";
    LC_PAPER = "en_US.UTF-8";
    LC_TELEPHONE = "en_US.UTF-8";
    LC_TIME = "en_US.UTF-8";
  };

  nixpkgs.config.allowUnfree = true;

  nix = {
    gc.automatic = true;
    package = pkgs.nixVersions.stable;
    settings = {
      trusted-users = ["@sudo" "@wheel" "jolheiser"];
      experimental-features = ["flakes" "nix-command" "repl-flake"];
      auto-optimise-store = true;
      warn-dirty = false;
      substituters = ["https://jolheiser.cachix.org"];
      trusted-public-keys = ["jolheiser.cachix.org-1:fiKkfTuHFqDK5ZOVxcqb4InUkKsrTvtMLISid7XvuVg="];
    };
  };

  system.activationScripts.diff = {
    supportsDryActivation = true;
    text = ''
      ${pkgs.nvd}/bin/nvd --nix-bin-dir=${pkgs.nix}/bin diff /run/current-system "$systemConfig"
    '';
  };

  services.tailscale.enable = true;

  environment = {
    systemPackages = with pkgs; [podman podman-compose podman-tui];
  };
}
