{pkgs, ...}: let
  username = "jolheiser";
in {
  imports = [./hardware.nix ../common/gui];

  boot = {
    kernelPackages = pkgs.linuxPackages_latest;
    kernelParams = ["quiet" "splash"];
    loader.grub = {
      enable = true;
      device = "/dev/sda";
      useOSProber = true;
      enableCryptodisk = true;
    };
  };

  boot.initrd.secrets = {"/crypto_keyfile.bin" = null;};

  boot.initrd.luks.devices = {
    "luks-1f9bde68-9c4c-423c-a95f-17aa170dd2b4".keyFile = "/crypto_keyfile.bin";
    "luks-a2ca1842-1ce0-437e-ba5e-8864a41e81cb" = {
      device = "/dev/disk/by-uuid/a2ca1842-1ce0-437e-ba5e-8864a41e81cb";
      keyFile = "/crypto_keyfile.bin";
    };
  };

  hardware = {bluetooth.enable = true;};

  networking = {
    hostName = "matcha";
    networkmanager.enable = true;
    firewall.enable = true;
  };

  services = {
    blueman.enable = true;
    openssh.enable = true;
    pcscd.enable = true;
  };

  virtualisation.docker.enable = true;

  users.users."${username}" = {
    extraGroups = ["wheel" "docker" "storage"];
    isNormalUser = true;
  };

  system.stateVersion = "22.11";
}
