{pkgs, ...}: {
  imports = [./hardware.nix ../common/gui];

  boot = {
    kernelPackages = pkgs.linuxPackages_latest;
    kernelParams = ["quiet" "splash"];
  };

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  boot.initrd.luks.devices."luks-c1c666de-2c68-4d50-98f1-3974ef424ff3".device = "/dev/disk/by-uuid/c1c666de-2c68-4d50-98f1-3974ef424ff3";

  hardware = {bluetooth.enable = true;};

  networking = {
    hostName = "sencha";
    networkmanager.enable = true;
    firewall = {
      enable = true;
      allowedTCPPorts = [8096];
    };
  };

  services = {
    blueman.enable = true;
    openssh.enable = true;
    pcscd.enable = true;
    printing = {
      enable = true;
      drivers = [pkgs.canon-cups-ufr2 pkgs.cnijfilter_4_00];
    };
    jellyfin.enable = true;
    mullvad-vpn = {
      enable = true;
      package = pkgs.mullvad-vpn;
    };
    resolved.enable = true;
  };

  virtualisation.docker.enable = true;

  users = {
    users = {
      olheiser.isNormalUser = true;
      jolheiser = {
        extraGroups = ["wheel" "docker" "storage"];
        isNormalUser = true;
      };
    };
    groups.media.members = ["jolheiser" "olheiser" "jellyfin"];
  };

  environment.systemPackages = with pkgs; [
    firefox
    gimp
    qbittorrent
  ];

  system.stateVersion = "22.11";
}
